@@ -1,5 +1,9 @@
+import logging
+
 from . import client as client
 from . import similarity as similarity
 from . import types as types
 
 __all__ = ("client", "similarity", "types")
+
+logging.getLogger(__name__).addHandler(logging.NullHandler())
